summaryrefslogtreecommitdiffstats
path: root/package/mac80211/patches/451-add-platform-eeprom-support-to-ath5k.patch
blob: 51867359a3b93f3a5651f40570c011552b21623c (plain)
1
2
3
4
5
6
7
8
9
10
11
12
13
14
15
16
17
18
19
20
21
22
23
24
25
26
27
28
29
30
31
32
33
34
35
36
37
38
39
40
41
42
43
44
45
46
47
48
49
50
51
52
53
54
55
56
--- a/drivers/net/wireless/ath/ath5k/eeprom.c
+++ b/drivers/net/wireless/ath/ath5k/eeprom.c
@@ -22,6 +22,8 @@
 \*************************************/
 
 #include <linux/slab.h>
+#include <linux/ath5k_platform.h>
+#include <linux/pci.h>
 
 #include "ath5k.h"
 #include "reg.h"
@@ -71,6 +73,18 @@ static u16 ath5k_eeprom_bin2freq(struct 
 static int ath5k_hw_eeprom_read(struct ath5k_hw *ah, u32 offset, u16 *data)
 {
 	u32 status, timeout;
+	struct ath5k_platform_data *pdata = NULL;
+
+	if (ah->ah_sc->pdev)
+		pdata = ah->ah_sc->pdev->dev.platform_data;
+
+	if (pdata && pdata->eeprom_data && pdata->eeprom_data[0] == AR5K_EEPROM_MAGIC_VALUE)
+	{
+		ATH5K_INFO(ah->ah_sc, "using eeprom-content from platform_data\n");
+		if (offset >= ATH5K_PLAT_EEP_MAX_WORDS) return -EIO;
+		*data = pdata->eeprom_data[offset];
+		return 0;
+	}
 
 	/*
 	 * Initialize EEPROM access
@@ -1760,7 +1774,7 @@ ath5k_eeprom_read_spur_chans(struct ath5
 }
 
 /*
  * Read the MAC address from eeprom
  */
 int ath5k_eeprom_read_mac(struct ath5k_hw *ah, u8 *mac)
 {
@@ -1768,6 +1782,16 @@ int ath5k_eeprom_read_mac(struct ath5k_h
 	u32 total, offset;
 	u16 data;
 	int octet, ret;
+	struct ath5k_platform_data *pdata = NULL;
+
+	if (ah->ah_sc->pdev)
+		pdata = ah->ah_sc->pdev->dev.platform_data;
+
+	if (pdata && pdata->macaddr)
+	{
+		memcpy(mac, pdata->macaddr, ETH_ALEN);
+		return 0;
+	}
 
 	ret = ath5k_hw_eeprom_read(ah, 0x20, &data);
 	if (ret)
@@ -1760,7 +1774,7 @@ ath5k_eeprom_read_spur_chans(struct ath5
 
 /*
- * Read the MAC address from eeprom
+ * Read the MAC address from eeprom or platform_data
  */
 int ath5k_eeprom_read_mac(struct ath5k_hw *ah, u8 *mac)